# -*- coding: utf-8 -*-
from setuphelpers import *

"""
{
   "key":"{E42A1466-88E2-4CD4-BB10-5DDF858232B5}",
   "name":"Zimbra Connector for Microsoft Outlook",
   "version":"0.0.0.1945",
   "install_date":"2025-01-06 00:00:00",
   "install_location":"",
   "uninstall_string":"MsiExec.exe /I{E42A1466-88E2-4CD4-BB10-5DDF858232B5}",
   "publisher":"Synacor, Inc.",
   "system_component":0,
   "win64":false
  }

"""


def install():
    if params.get("install_with_luti", False):
        WAPT.install("tis-microsoft-office-365-business")

    office_arch = registry_readstring(HKEY_LOCAL_MACHINE, "SOFTWARE\Microsoft\Office\ClickToRun\Configuration", "Platform")
    if office_arch == "x86":
        bin_name = 'ZimbraConnectorOLK_x86.msi'
    else:
        bin_name = 'ZimbraConnectorOLK_x64.msi'

    try:
        install_msi_if_needed(
            bin_name,
            min_version=control.get_software_version(),
            timeout=300,
            keywords="Zimbra Connector",
            get_version=get_version
        )
    except Exception as e:
        if not installed_softwares("Outlook"):
            print(f"INFO: Microsoft Outlook needs to be installed.")
        raise

    # Customize installation
    with reg_openkey_noredir(HKEY_LOCAL_MACHINE, 'SOFTWARE\Zimbra', sam=KEY_WRITE, create_if_missing=True) as key:
        reg_setvalue(key, 'SkipVersionUpgrade', '65535', REG_SZ)  # disable auto-update
        # reg_setvalue(key, 'ZimbraServerName', 'smtp.mydomain.tld', REG_SZ)  # Zimbra server name
        # reg_setvalue(key, 'ZimbraServerPort', 443, REG_DWORD)  # Zimbra server port
        # reg_setvalue(key, 'ZimbraConnectionMethod', 1, REG_DWORD)  # use SSL
        # reg_setvalue(key, 'GalSyncDisableAliases', 1, REG_DWORD)  # disable alias in GAL
        # reg_setvalue(key, 'SigSyncEnabled', 0, REG_DWORD)  # disable signature sync


def get_version(key):
    return key['version'].split('.')[-1]


def audit():
    audit_result = "OK"

    office_arch = registry_readstring(HKEY_LOCAL_MACHINE, "SOFTWARE\Microsoft\Office\ClickToRun\Configuration", "Platform")
    regpath = 'SOFTWARE\Microsoft\Office\ClickToRun\REGISTRY\MACHINE\Software\Microsoft\Windows\Windows Search\Preferences'
    if is64() and office_arch == "x86":
        regpath = 'SOFTWARE\Microsoft\Office\ClickToRun\REGISTRY\MACHINE\Software\Wow6432Node\Microsoft\Windows\Windows Search\Preferences'

    # Fix Windows Search ZCO registry key if needed
    # https://wiki.zimbra.com/wiki/Summary_of_the_registry_keys_that_ZCO_uses
    # https://forums.zimbra.org/viewtopic.php?t=67734

    regpath = 'SOFTWARE\Microsoft\Office\ClickToRun\REGISTRY\MACHINE\Software\Microsoft\Windows\Windows Search\Preferences'
    for key in ['{D00FDE68-3E80-4f8c-899D-D9DD16BA7D1D}', '{FA9628A0-F223-4d5d-B314-E01BC8100572}']:
        if registry_readstring(HKEY_LOCAL_MACHINE, regpath, key) != "1":
                print(f'Fixing Windows Search ZCO registry key {key}...')
                registry_set(HKEY_LOCAL_MACHINE, regpath, key, 1, REG_DWORD)
                audit_result = "WARNING"

    return audit_result